function [Yf_date , Yf_sats, Yf_acc, satsalm, Yf_comment] = readsp3(yfile)
// Einlesen: SP3-c Dateien (nur Header) (sehr experimentell)
//
// in : yfile: (als Textstring vollstndiger Dateipfad, oder)
//      als logische Einheit, wie sie von <i>mopen</i> gegeben wird. 
//          
// out: .....
//
// Copyright (c) area7/Christof Schulze  2007
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  satsalm=[]; numsats=[];
  Yf_date=[];
  Yf_sats=[];
  Yf_acc=[];
  Yf_comment=[];
  file_type=[];
  time_sys=[];
  block=[];


// Display mode
  mode(0);
// Display warning for floating point exception
  ieee(1);

  Yf = mgetl(yfile);  //  This is your input file

  Yf_lines = int(size(Yf,1));
  parserror=[];
  linr=0;

  line = Yf(1);                                       // Line ---   1
  if ('#c' <> part(line,1:2) ) then
    Yf_date = -1;
    // falsche SP3-Version oder keine SP3-Datei
    parseerror = line;
    return;
  end;

  file_type  = (part(line,3:3));                      // Filetype P or V (only P supported)
  if (file_type <> 'P') then
    Yf_date = 0;
    // Falscher Dateityp nur P wird untersttzt
    return;
  end;


  Yf_date(1) = parse_sp3_date(part(line,4:31));       // Date datenum(yyyy,mm,dd,hh,ss)
  Yf_date(4) = evstr(part(line,33:39));               // Number of Epochs in File

  line = Yf(2);                                       // Line ---   2
  if ('##' <> part(line,1:2) ) then
    Yf_date(1)=-1; Yf_date(4)=0;
    // keine SP3-Datei
    parseerror = line;
    return;
  end;

  Yf_date(2) = evstr(part(line,4:7));                 // GPS Week
  Yf_date(3) = evstr(part(line,9:23));                // Seconds of Week
  epoch_diff = evstr(part(line,25:38));               // Epoch Intervall
  date_mjd   = evstr(part(line,40:44));               // Mod Jul Day
  date_mjd   = date_mjd + evstr(part(line,46:60));    // Fractional Day

  line = Yf(3);                                       // Line ---   3
  if ('+ ' <> part(line,1:2) ) then
    // keine SP3-Datei
    parseerror = line;
    return;
  end;
  numsats   = evstr(part(line,5:6));                  // Number of Sats
  [Yf_sats,err]   = parse_sp3_sats(part(line,10:60), 'name'); // Sat numbers
  if (err<>0) then parseerror=line; return; end;

  line = Yf(4);                                       // Line ---   4
  if ('+ ' <> part(line,1:2) ) then
    // keine SP3-Datei
    parseerror = line;
    return;
  end;

  [tmp_sats,err] = parse_sp3_sats(part(line,10:60), 'name');
  if (err<>0) then parseerror=line; return; end;
  Yf_sats   = cat(1,Yf_sats, tmp_sats);               // Sat numbers

  line = Yf(5);                                       // Line ---   5
  if ('+ ' <> part(line,1:2) ) then
    // keine SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_sats,err] = parse_sp3_sats(part(line,10:60), 'name');
  if (err<>0) then parseerror=line; return; end;
  Yf_sats   = cat(1,Yf_sats, tmp_sats);               // Sat numbers

  line = Yf(6);                                       // Line ---   6
  if ('+ ' <> part(line,1:2) ) then
    // keine SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_sats,err] = parse_sp3_sats(part(line,10:60), 'name');
  if (err<>0) then parseerror=line; return; end;
  Yf_sats   = cat(1,Yf_sats, tmp_sats);               // Sat numbers

  line = Yf(7);                                       // Line ---   7
  if ('+ ' <> part(line,1:2) ) then
    // keine SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_sats,err] = parse_sp3_sats(part(line,10:60), 'name');
  if (err<>0) then parseerror=line; return; end;
  Yf_sats   = cat(1,Yf_sats, tmp_sats);               // Sat numbers

  if size(Yf_sats,1)<>numsats then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;

  line = Yf(8);                                       // Line ---   8
  if ('++' <> part(line,1:2) ) then
    // keine SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_acc,err] = parse_sp3_sats(part(line,10:60), 'acc');
  if (err<>0) then parseerror=line; return; end;
  Yf_acc   = 2^tmp_acc;                               // Sat Accuracy

  line = Yf(9);                                       // Line ---   9
  if ('++' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_acc,err] = parse_sp3_sats(part(line,10:60), 'acc');
  if (err<>0) then parseerror=line; return; end;
  Yf_acc   = cat(1,Yf_acc, 2^tmp_acc);                // Sat Accuracy

  line = Yf(10);                                      // Line ---  10
  if ('++' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_acc,err] = parse_sp3_sats(part(line,10:60), 'acc');
  if (err<>0) then parseerror=line; return; end;
  Yf_acc   = cat(1,Yf_acc, 2^tmp_acc);                // Sat Accuracy

  line = Yf(11);                                      // Line ---  11
  if ('++' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_acc,err] = parse_sp3_sats(part(line,10:60), 'acc');
  if (err<>0) then parseerror=line; return; end;
  Yf_acc   = cat(1,Yf_acc, 2^tmp_acc);                // Sat Accuracy

  line = Yf(12);                                      // Line ---  12
  if ('++' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  [tmp_acc,err] = parse_sp3_sats(part(line,10:60), 'acc');
  if (err<>0) then parseerror=line; return; end;
  Yf_acc   = cat(1,Yf_acc, 2^tmp_acc);                  // Sat Accuracy

  if size(Yf_acc,1)<>numsats then
    Yf_acc = Yf_acc(1:numsats);
    //parseerror = line;
    //return;
  end;

  line = Yf(13);                                      // Line ---  13
  if ('%c' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  file_type = part(line,4:5);                         // Filetype
  time_sys  = part(line, 10:12);                      // Time system (GPS)

  line = Yf(14);                                      // Line ---  14
  if ('%c' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  file_type = part(line,4:5);                         // Filetype
  time_sys  = part(line, 10:12);                      // Time system (GPS)

  line = Yf(15);                                      // Line ---  15
  if ('%f' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  base_values = evstr(part(line,4:13));               // Base of Pos (or Velocity) [mm or 10^-4 mm/sec]
  base_clkrate= evstr(part(line,15:26));              // Base for Clock/rate [psec or 10^-4 psec/sec]

  line = Yf(16);                                      // Line ---  16
  if ('%f' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;

  line = Yf(17);                                      // Line ---  17
  if ('%i' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;

  line = Yf(18);                                      // Line ---  18
  if ('%i' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;

  line = Yf(19);                                      // Line ---  19
  if ('/*' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  Yf_comment(1) = stripblanks(part(line,4:60));       // comment

  line = Yf(20);                                      // Line ---  20
  if ('/*' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  Yf_comment(2) = stripblanks(part(line,4:60));       // comment

  line = Yf(21);                                      // Line ---  21
  if ('/*' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  Yf_comment(3) = stripblanks(part(line,4:60));       // comment

  line = Yf(22);                                      // Line ---  22
  if ('/*' <> part(line,1:2) ) then
    // fehler in SP3-Datei
    parseerror = line;
    return;
  end;
  Yf_comment(4) = stripblanks(part(line,4:60));       // comment

  satsalm = zeros(numsats,13);
  //block_matrix=zeros(numsats,13);
  init_lnnr=23;                                       // Line ---  23
  block_matrix_count=1;
  tmp_date=0; epoche=0;
  tmpsymbol1=''; tmpsymbol2='';tmpdata=[];
  for lnnr=init_lnnr:(size(Yf,1)-1) do
    line = Yf(lnnr);
    if ('* ' == part(line,1:2)) then                  // Epoche header
      [tmp_date,epoche,err] = parse_sp3_date(part(line,4:31));
    else
      [tmpdata ,tmpsymbol1, tmpsymbol2, err] = parse_sp3_databl(line);
      if err<>0 then
        mprintf("Fehler in Zeile: %i",lnnr);
      end;
      satsalm(block_matrix_count,:) = [Yf_date(2), epoche, str2code(tmpsymbol1), str2code(tmpsymbol2), tmpdata(1), tmpdata(2), tmpdata(3), tmpdata(4), tmpdata(5), tmpdata(6), tmpdata(7), tmpdata(8),tmpdata(9)];    
      block_matrix_count = block_matrix_count + 1;
    end
  end;

  //satsalm = block_matrix;

endfunction;

function [bdata, symbol1, symbol2, perr] = parse_sp3_databl(dblockline)
// Funktion parst eine Zeile eines Datenblocks
  perr=0;
  
  symbol1=part(dblockline,1);                       // Datentyp: P-Position, V-Bewegung
  symbol2=part(dblockline,2);                       // Satelite Type G-GPS R-Glonass M-Mixed
  
  if symbol1=='P' then
    [satid,perr]   =evstr(part(dblockline,3:4));
    [xx,perr]      =evstr(part(dblockline,5:18))*1000;
    [yy,perr]      =evstr(part(dblockline,19:32))*1000;
    [zz,perr]      =evstr(part(dblockline,33:46))*1000;
    [clk,perr]     =evstr(part(dblockline,47:60));
    if (clk<>999999.999999) then
     [sigma_x,perr]=evstr(part(dblockline,62:63));
     if sigma_x==[] then sigma_x=0; else sigma_x = base_values^sigma_x; end;
     [sigma_y,perr]=evstr(part(dblockline,65:66));
     if sigma_y==[] then sigma_y=0; else sigma_y = base_values^sigma_y; end;
     [sigma_z,perr]=evstr(part(dblockline,68:69));
     if sigma_z==[] then sigma_z=0; else sigma_z = base_values^sigma_z; end;
     [sigma_c,perr]=evstr(part(dblockline,71:73));
     if sigma_c==[] then sigma_c=0; else sigma_c = base_clkrate^sigma_c; end;
    else
     sigma_x=0;
     sigma_y=0;
     sigma_z=0;
     sigma_c=0;
    end;
    bdata=[satid,xx,yy,zz,clk,sigma_x,sigma_y,sigma_z,sigma_c]
  else // TODO
    perr=4;
    mprintf("V*,EP,EV Datenstze werden nicht untersttzt\n");
  end;
  
  bdata = bdata;   //[1,2,3]

endfunction;

function [rdate, secsofday, err] = parse_sp3_date(datestring)
// Funktion parst einen Teistring mit Datumsangabe aus einer SP3-Datei.
  err=0;
  [year,errp] = evstr(part(datestring,1:4)); err=err+errp;
  [month,errp]= evstr(part(datestring,6:7)); err=err+errp;
  [day,errp]  = evstr(part(datestring,9:10)); err=err+errp;
  [hour,errp] = evstr(part(datestring,12:13)); err=err+errp;
  [minu,errp] = evstr(part(datestring,15:16)); err=err+errp;
  [secs,errp] = evstr(part(datestring,18:28)); err=err+errp;
  rdate = datenum(year,month,day,hour,minu,secs);
  secsofday = (((hour*60)+minu)*60)+secs;
endfunction;

function [rsats, err] = parse_sp3_sats(satstring, datatype)
// Funktion teilt die lange Auflistung der Sat-Namen in eine Matrix auf (Zeilen 3-12)
  rsats=[]; s=1; i=1; err=0;
  
  if (length(satstring)<>51) then
    rsats=[0];
    err=4;
    return;
  end;
  
  if (datatype=='name') then
    while (i<=length(satstring)) do
      [tstr,errp] = evstr(part(satstring,i:i+2));
      if (errp<>0) then
        rsats(s) = part(satstring,i:i+2);
        s=s+1;
      elseif (tstr==0) ,
        err=err;
      else
        err=err+4;
        return;
      end;
      i = i+3; 
    end;
  elseif (datatype=='acc') then
    while (i<=length(satstring)) do
      [tstr,errp] = evstr(part(satstring,i:i+2));
      if (errp==0) then
        rsats(s) = tstr;
        s=s+1;
      //elseif (tstr==0) ,
        //err=err;
      else
        err=err+4;
        return;
      end;
      i = i+3; 
    end;
  end;

endfunction;
