function [epsilon_0,delta_epsilon,delta_psi] = nutwinkel(t)
// Berechnet die mittlere Ekliptikschiefe epsilon_0,
// die Nutation in der Lnge delta_psi und in Schiefe delta_epsilon.
//
// in : t	- Zeit von der Epoche J2000
//      [in Julianischen Jahrhunderten (von 36525 Tagen)]
//
// out: eps0   - mittlere Ekliptikschiefe [in dezimalen Grad]
//      deleps - Nutation in Schiefe	 [in dezimalen Grad]
//      delpsi - Nutation in Lnge	 [in dezimalen Grad]
//
// Genauigkeit liegt bei ca. einer Bogensekunde. (matrixfhig)
// Copyright (c) area7/Christof Schulze  2007
//--------------------------------------------------------------

// Zeitdifferenz von J2000
d  =  t .* 36525;

// Hilfsfunktionen
f1 = (125 - 0.05295 .* d) .* (%pi/180.0);
f2 = (200.9 + 1.97129 .* d) .* (%pi/180.0);

epsilon_0   = (84381.448 - 46.815 .* t) ./ 3600;
delta_psi = (-0.0048 .* sin(f1) - 0.0004 .* sin(f2));
delta_epsilon = ( 0.0026 .* cos(f1) + 0.0002 .* cos(f2));

endfunction
