function [gast,gmst] = ut12gast(t, ut1)
// Berechnet die wahre Sternzeit Greenwich (GAST) aus UT1 und J2000.0
// Calculates the Greenwich Apparent Sideral Time (GAST) from UT1 and J2000.0
//
// in :	t    - Zeit in der Epoche J2000.0
//             [Julianischen Jahrhunderten (von 36525 Tagen)]
//      ut1  - Weltzeit Greenwich [dezimale Stunden]
//
// out:	gast - Wahre Sternzeit Greenwich [dezimale Stunden]
//      gmst - Mittlere Sternzeit Greenwich [dezimale Stunden]
//
// Die Genauigkeit liegt wegen der Genauigkeit der Funktion fr die Nutation
// nur bei ~ 0,1 [sec].
//
// (matrixfhig) (experimentell !!!)
//
// Copyright (c) area7/Christof Schulze  2007
//--------------------------------------------------------------

// Ouput variables initialisation (not found in input variables)
  gast=[]; gmst=[];

// Display mode
  mode(0);

// Display warning for floating point exception
  ieee(1);

// laden der nutwinkel-Funktion (falls noch nicht geschehen)
  if (~isdef(nutwinkel)) then
    getf(%GEOlib_DIR+'/phys/nutwinkel.sci');
  end

  gmst = (ut1*3600 + 24110.54841 + 8640184.812866*t + 0.093104*t.^2 - 6.2e-6*t.^3) / 3600;


  [epsilon_0, delta_epsilon, delta_psi] = nutwink(t);
  epsi = ((epsilon_0 + delta_epsilon) / 180) * %pi;
  eq   = delta_psi .* cos(epsi);    // ersetzen durch aequiKor()

  gast = gmst + eq/15;              // ersetzen durch aequiKor()

  rem_gast = gast + 24 - 24 * fix(gast/24);
  gast= rem_gast - 24 * fix(rem_gast/24);
  
  rem_gmst = gmst + 24 - 24 * fix(gmst/24);
  gmst= rem_gmst - 24 * fix(rem_gmst/24);
  
  //gast = (gast - fix(gast /24)*24 + 24) - fix((gast - fix(gast / 24)*24 + 24)/24)*24;
  //gmst = (gmst - fix(gmst /24)*24 + 24) - fix((gmst - fix(gmst / 24)*24 + 24)/24)*24;

endfunction;